@@ -34,9 +34,9 @@ class ProgPercent(Prog):
         """Prints formatted integer percentage and tracked time to the screen."""
         self._stream_out('\r[%3d %%]' % (self.perc))
         if self.track:
-            self._stream_out('   elapsed: %.3f sec' % self._elapsed())
+            self._stream_out('%3selapsed [sec]: %.3f' % ('', self._elapsed()))
             if self._calc_eta():
-                self._stream_out(' | eta: %.3f sec' % self._calc_eta())
+                self._stream_out('%2s| ETA [sec]: %.3f' % ('', self._calc_eta()))
             self._stream_flush()
 
     def update(self):
@@ -49,5 +49,5 @@ class ProgPercent(Prog):
             self._stream_flush()
         if self.cnt == self.max_iter:
             if self.track:
-                self._stream_out(' | eta: 0.000 sec')
-            self._stream_out('\n') 
+                self._stream_out('%2s| ETA [sec]: %.3f' % ('',0))
+                self._stream_out('\n') 
